import type { Router } from 'vue-router'
import NProgress from 'nprogress'
import config from '/config/config'
import { useStoreRoutes, useStoreSettings } from '@gx-vuex'
import getPageTitle from '@/utils/pageTitle'
import { scrollToContainer } from '@/utils/util'
import { createStateGuard } from './stateGuard'
import { createPermissionGuard } from './permissions'

const {
  routerLoadTime,
  routesWhiteList
} = config.defaultSettings

export function setupRouterGuard(router: Router) {
  createPageGuard(router)
  createPageLoadingGuard(router)
  createScrollGuard(router)
  createProgressGuard(router)
  createPermissionGuard(router)
  createStateGuard(router)
}

export function createPageGuard(router: Router) {
  const routes = useStoreRoutes()
  const settings = useStoreSettings()

  router.afterEach((to) => {
    const { meta }: any = to
    document.title = getPageTitle(meta.title || '')
    if (
      settings.layout !== 'wide' &&
      routes.routerLoadList.every(item => item !== to.path) &&
      routesWhiteList.indexOf(to.path) === -1
    ) {
      routes.addRouterLoadList(to.path)
    }
  })
}

export function createPageLoadingGuard(router: Router) {
  const routes = useStoreRoutes()
  const settings = useStoreSettings()

  router.beforeEach(async (to) => {
    if (
      settings.layout !== 'wide' &&
      routes.routerLoadList.every(item => item !== to.path) &&
      routesWhiteList.indexOf(to.path) === -1
    ) {
      routes.changeValue('routerLoading', true)
    }

    return true
  })

  router.afterEach((_) => {
    if (settings.layout === 'wide') {
      routes.changeValue('routerLoading', false)
    } else {
      setTimeout(() => {
        routes.changeValue('routerLoading', false)
      }, routerLoadTime || 200)
    }
  })
}

export function createScrollGuard(router: Router) {
  router.afterEach((_) => {
    scrollToContainer(0)
  })
}

export function createProgressGuard(router: Router) {
  const settings = useStoreSettings()
  router.beforeEach(() => {
    if (settings.showProgressBar) NProgress.start()
    return true
  })

  router.afterEach(() => {
    NProgress.done()
  })
}
