import type { Router, RouteRecordRaw } from 'vue-router'
import config from '/config/config'
import { useStoreUser, useStoreRoutes, useStorePermission } from '@gx-vuex'

const {
  authentication,
  loginInterception,
  recordRoute,
  routesWhiteList
} = config.defaultSettings

export function createPermissionGuard(router: Router) {
  const userStore = useStoreUser()
  const routeStore = useStoreRoutes()
  const permissionStore = useStorePermission()

  router.beforeEach(async (to, _, next) => {
    const token = loginInterception || userStore.accessToken

    if (routesWhiteList.includes(to.path)) {
      if ((to.path === '/') && token) {
        next({ path: '/', replace: true })
      }
      next()
      return
    }

    if (!token) {
      userStore.resetPermissions()
      if (recordRoute) {
        next({ path: '/user/login', query: { redirect: to.path }, replace: true })
      } else {
        next({ path: '/user/login', replace: true })
      }
      return
    }

    const hasRoles = permissionStore.role.length > 0

    if (hasRoles) {
      next()
      return
    }

    const userInfo = loginInterception
      ? await userStore.queryUserInfo() : await userStore.setVirtualRoles()

    if (!userInfo) {
      userStore.resetPermissions()
      if (recordRoute) {
        next({ path: '/user/login', query: { redirect: to.path }, replace: true })
      } else {
        next({ path: '/user/login', replace: true })
      }
      return
    }

    const routes = authentication === 'all'
      ? await routeStore.setAllRoutes()
      : await routeStore.setRoutes()

    routeStore.changeValue('meunLoading', false)

    if (routes?.length) {
      routes.forEach((route) => {
        router.addRoute(route as RouteRecordRaw)
      })
      next({ path: to.fullPath, replace: true })
      return
    }
    next({ path: '/exception/403', replace: true })
  })
}
