import dayjs from 'dayjs'
import config from '/config/config'
import { deepCopy, scrollTo, getBlobUrl } from '@gx-design-vue/pro-utils'

const { viewScrollRoot } = config.defaultSettings

export function timeFix() {
  const time = new Date()
  const hour = time.getHours()
  return hour < 9 ? '早上好' : hour <= 11 ? '上午好' : hour <= 13 ? '中午好' : hour < 20 ? '下午好' : '晚上好'
}

/**
 * @Author      gaoxiang
 * @DateTime    2020/7/23
 * @lastTime    2020/7/23
 * @description 去除空格
 */
export function trim(str: string, isGlobal?: boolean) {
  if (typeof str === 'undefined' || str.length === 0) return ''
  let result
  result = str.replace(/(^\s+)|(\s+$)/g, '')
  if (isGlobal) {
    result = result.replace(/\s/g, '')
  }
  return result
}

/**
 * @Author      gx12358
 * @DateTime    2021/11/3
 * @lastTime    2021/11/3
 * @description get参数处理
 */
export function tansParams(params) {
  let result = ''
  for (const propName of Object.keys(params)) {
    const value = params[propName]
    const part = encodeURIComponent(propName) + '='
    if (value !== null && typeof (value) !== 'undefined' && value !== '') {
      if (typeof value === 'object') {
        for (const key of Object.keys(value)) {
          if (value[key] !== null && typeof (value[key]) !== 'undefined') {
            const params = propName + '[' + key + ']'
            const subPart = encodeURIComponent(params) + '='
            result += subPart + encodeURIComponent(value[key]) + '&'
          }
        }
      } else {
        result += part + encodeURIComponent(value) + '&'
      }
    }
  }
  return result
}

/**
 * @Author      gaoxiang
 * @DateTime    2020/11/1
 * @lastTime    2020/11/1
 * @description 处理table多选翻页 selectItems 丢失问题
 */
export function handleSelectPage(config: {
  rowKey?: string;
  tableData: any[];
  selectItems: any[];
  oldSelectItems: any[];
}) {
  const {
    tableData,
    oldSelectItems,
    selectItems,
    rowKey = 'id'
  } = config
  const currentSelectItems = oldSelectItems.filter((item: any) => tableData.some(el =>
    el[rowKey] === item[rowKey])
  )
  let newSelectItems = deepCopy(oldSelectItems)
  if (currentSelectItems.length < selectItems.length) {
    const pushItems = selectItems.filter((item: any) => !currentSelectItems.find(el =>
      el[rowKey] === item[rowKey])
    )
    pushItems.map((item: any) => {
      newSelectItems.push(item)
      return item
    })
  } else {
    const filterItems = currentSelectItems.filter((item: any) =>
      !selectItems.find((el: any) => el[rowKey] === item[rowKey])
    )
    newSelectItems = newSelectItems.filter((item: any) =>
      !filterItems.find((el: any) => el[rowKey] === item[rowKey])
    )
  }
  return newSelectItems
}

/**
 * @Author      gaoxiang
 * @DateTime    2019/11/29
 * @lastTime    2019/11/29
 * @description 排序（从大到小）
 */
export function compareToMin(obj1: any, obj2: any, key: string) {
  const val1 = obj1[key]
  const val2 = obj2[key]
  let result = 0
  if (val1 < val2) {
    result = 0
  } else if (val1 > val2) {
    result = -1
  }
  return result
}

/**
 * @Author      gaoxiang
 * @DateTime    2019/11/29
 * @lastTime    2019/11/29
 * @description 排序（从小到大）
 */
export function compareToMax(obj1: any, obj2: any, key: string) {
  const val1 = obj1[key]
  const val2 = obj2[key]
  let result = 0
  if (val1 < val2) {
    result = -1
  } else if (val1 > val2) {
    result = 0
  }
  return result
}

function mGetDate() {
  const date = new Date()
  const year = date.getFullYear()
  const month = date.getMonth() + 1
  const d = new Date(year, month, 0)
  return d.getDate()
}

/**
 * @Author      gx12358
 * @DateTime    2022/8/4
 * @lastTime    2022/8/4
 * @description 处理时间展示（dayjs）
 */
export function momentFromNow(time) {
  return dayjs(time).fromNow()
}

/**
 * @Author      gx12358
 * @DateTime    2022/8/4
 * @lastTime    2022/8/4
 * @description 处理时间展示
 */
export function handleTimeShow(date: string) {
  const date3 = new Date().getTime() - new Date(date.replace(/\-/g, '/')).getTime() // 时间差的毫秒数
  const days = Math.floor(date3 / (24 * 3600 * 1000))
  // 计算出小时数
  const leave1 = date3 % (24 * 3600 * 1000) // 计算天数后剩余的毫秒数
  const hours = Math.floor(leave1 / (3600 * 1000))
  // 计算相差分钟数
  const leave2 = leave1 % (3600 * 1000) // 计算小时数后剩余的毫秒数
  const minutes = Math.floor(leave2 / (60 * 1000))
  // 计算相差秒数
  const leave3 = leave2 % (60 * 1000) // 计算分钟数后剩余的毫秒数
  const seconds = Math.round(leave3 / 1000)
  if (
    days === 0 &&
    hours === 0 &&
    minutes === 0 &&
    seconds < 60
  ) {
    return '刚刚'
  } else if (
    days === 0 &&
    hours === 0 &&
    minutes < 60
  ) {
    return `${minutes}分钟前`
  } else if (
    days === 0 &&
    hours < 24
  ) {
    return `${hours}小时前`
  } else if (
    days < mGetDate()
  ) {
    return dayjs(date.replace(/\-/g, '/')).format('MM-dd hh:mm')
  } else {
    return dayjs(date.replace(/\-/g, '/')).format('yyyy-MM-dd')
  }
}

/**
 * @Author      gx12358
 * @DateTime    2021/1/11
 * @lastTime    2021/1/11
 * @description 图片ur地址转file对象
 */
export function getImageFileFromUrl(url = '', imageName: string) {
  return new Promise((resolve) => {
    let blob: any = null
    const xhr = new XMLHttpRequest()
    xhr.open('GET', url, true)
    xhr.responseType = 'blob'
    xhr.onload = () => {
      blob = xhr.response
      const imgFile = new File([ blob ], imageName, { type: 'image/png' })
      resolve(imgFile)
    }
    xhr.send()
  })
}

/**
 * @Author      gx12358
 * @DateTime    2021/1/11
 * @lastTime    2021/1/11
 * @description 本地资源获取blob地址
 */
export function getLocalBlob(url = '') {
  return new Promise((resolve) => {
    let blob: any = null
    const xhr = new XMLHttpRequest()
    xhr.open('GET', url, true)
    xhr.responseType = 'blob'
    xhr.onload = () => {
      blob = xhr.response
      resolve(getBlobUrl(blob))
    }
    xhr.send()
  })
}

/**
 * @Author      gx12358
 * @DateTime    2022/10/11
 * @lastTime    2022/10/11
 * @description 判断元素到上一个元素的距离
 */
export function handleOffsetTop(targetNode: HTMLInputElement) {
  let totalLeft = 0
  let totalTop = 0
  if (!targetNode) return { left: totalLeft, top: totalTop }
  let parentNode = <HTMLElement>targetNode.offsetParent
  //首先把自己本身的相加
  totalLeft += targetNode.offsetLeft
  totalTop += targetNode.offsetTop
  //现在开始一级一级往上查找，只要没有遇到body，我们就把父级参照物的边框和偏移相加
  while (parentNode) {
    if (navigator.userAgent.indexOf('MSIE 8.0') === -1) {
      //不是IE8我们才进行累加父级参照物的边框
      totalTop += parentNode.clientTop
      totalLeft += parentNode.clientLeft
    }
    //把父级参照物的偏移相加
    totalTop += parentNode.offsetTop
    totalLeft += parentNode.offsetLeft
    parentNode = <HTMLElement>parentNode.offsetParent
  }
  return { left: totalLeft, top: totalTop }
}

/**
 * @Author      gx12358
 * @DateTime    2022/10/11
 * @lastTime    2022/10/11
 * @description 滚动到固定位置
 */
export function scrollToContainer(count: number, root?: string) {
  scrollTo(count || 0, {
    getContainer: () => document.querySelector(viewScrollRoot || root) as HTMLInputElement,
    duration: 200
  })
}
