import type { Plugin, PluginOption } from 'vite'

import vue from '@vitejs/plugin-vue'
import vueJsx from '@vitejs/plugin-vue-jsx'

import vueSetupExtend from 'vite-plugin-vue-setup-extend'

import { presetAttributify, presetUno, transformerDirectives } from 'unocss'
import Unocss from 'unocss/vite'

import { configHtmlPlugin } from './html'
import { configMockPlugin } from './mock'
import { createAutoImport } from './autoImport'

export function createVitePlugins(viteEnv: ViteEnv, isBuild: boolean) {
  const {
    VITE_USE_MOCK
  } = viteEnv

  const vitePlugins: (Plugin | PluginOption[])[] = [
    // have to
    vue(),
    // have to
    vueJsx()
  ]

  // unocss
  vitePlugins.push(Unocss({
    presets: [
      presetAttributify(),
      presetUno()
    ],
    transformers: [ transformerDirectives() ]
  }))

  // vite-plugin-vue-setup-extend
  vitePlugins.push(vueSetupExtend())

  // vite-plugin-html
  vitePlugins.push(configHtmlPlugin(viteEnv, isBuild))

  // vite-plugin-mock
  VITE_USE_MOCK && vitePlugins.push(configMockPlugin(isBuild))


  // unplugin-auto-import/vite
  vitePlugins.push(createAutoImport())

  return vitePlugins
}
