import type { Ref } from 'vue'
import { ref, watch } from 'vue'
import { closeToast, showLoadingToast } from 'vant'
import type { PageLoadingTpe } from '@/components/PageContainer'

export type SetLoadingParams<T> = { value: T; type?: PageLoadingTpe; message?: string }

type ChangeLoadingFn<T> = ({ value, type, message }: SetLoadingParams<T>) => void

export default function usePageLoading<T, R = Ref<T>>({
  defaultType,
  defaultMessage,
  defaultLoading
}: {
  defaultType?: PageLoadingTpe;
  defaultMessage?: string;
  defaultLoading?: T | (() => T);
}): [ R, ChangeLoadingFn<T> ] {

  const initValue: T =
    typeof defaultLoading === 'function' ? (defaultLoading as any)() : defaultLoading

  const pageLoading = ref(initValue) as Ref<T>

  const loadingMessage = ref(defaultMessage)

  const loadingType = ref(defaultType)

  watch(() => pageLoading.value, (val) => {
    if (val) {
      if (loadingType.value === 'toast') {
        showLoadingToast({
          duration: 0,
          forbidClick: true,
          message: loadingMessage.value || '加载中'
        })
      } else {
        closeToast()
      }
    } else {
      closeToast()
    }
  }, {
    deep: true,
    immediate: true
  })

  const changeLoading = ({ value, type, message }: SetLoadingParams<T>) => {
    pageLoading.value = value
    loadingMessage.value = message
    if (type) loadingType.value = type
  }

  return [ pageLoading as unknown as R, changeLoading ]
}
