import { reactive, toRefs } from 'vue'
import { defineStore } from 'pinia'
import { deepCopy } from '@/utils/util'

/**
 * @Author      gx12358
 * @DateTime    2022/1/11
 * @lastTime    2022/1/11
 * @description store-global 全局属性
 */
export interface GlobalState {
  token?: string; // app token
}

type GlobalStateKey = keyof GlobalState

export const useStoreGlobal = defineStore('global', () => {
  const state = reactive<GlobalState>({
    token: ''
  })

  const setGlobalData: (params: Partial<Record<GlobalStateKey, GlobalState[GlobalStateKey]>>) => void = (params) => {
    Object.assign(state, deepCopy(params))
  }

  return {
    ...toRefs(state),
    setGlobalData
  }
})
