const toString = Object.prototype.toString

function is(val, type) {
  return toString.call(val) === `[object ${type}]`
}

const isClient = typeof window !== 'undefined'

const noop = () => {}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判读是否为外链
 * @param path
 * @returns {boolean}
 */
function isExternal(path) {
  return /^(https?:|mailto:|tel:)/.test(path)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 校验密码是否小于6位
 * @param value
 * @returns {boolean}
 */
function isPassword(value) {
  return value.length >= 6
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否为数字
 * @param value
 * @returns {boolean}
 */
function isNumber(val) {
  return typeof val === 'number'
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否是名称
 * @param value
 * @returns {boolean}
 */
function isName(value) {
  const reg = /^[\u4e00-\u9fa5a-zA-Z0-9]+$/
  return reg.test(value)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否为IP
 * @param ip
 * @returns {boolean}
 */
function isIP(ip) {
  const reg = /^(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])$/
  return reg.test(ip)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否是传统网站
 * @param url
 * @returns {boolean}
 */
function isUrl(url) {
  const reg = /^(https?|ftp):\/\/([a-zA-Z0-9.-]+(:[a-zA-Z0-9.&%$-]+)*@)*((25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]?)(\.(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9]?[0-9])){3}|([a-zA-Z0-9-]+\.)*[a-zA-Z0-9-]+\.(com|edu|gov|int|mil|net|org|biz|arpa|info|name|pro|aero|coop|museum|[a-zA-Z]{2}))(:[0-9]+)*(\/($|[a-zA-Z0-9.,?'\\+&%$#=~_-]+))*$/
  return reg.test(url)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否是小写字母
 * @param value
 * @returns {boolean}
 */
function isLowerCase(value) {
  const reg = /^[a-z]+$/
  return reg.test(value)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否是大写字母
 * @param value
 * @returns {boolean}
 */
function isUpperCase(value) {
  const reg = /^[A-Z]+$/
  return reg.test(value)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否是大写字母开头
 * @param value
 * @returns {boolean}
 */
function isAlphabets(value) {
  const reg = /^[A-Za-z]+$/
  return reg.test(value)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否是字符串
 * @param value
 * @returns {boolean}
 */
function isString(value) {
  return typeof value === 'string' || value instanceof String
}

function isBoolean(val){
  return is(val, 'Boolean')
}

function isFunction(func) {
  return (typeof func === 'function' || Object.prototype.toString.call(func) === '[object Function]')
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否是数组
 * @param arg
 * @returns {arg is any[]|boolean}
 */
function isArray(arg) {
  if (typeof Array.isArray === 'undefined') {
    return Object.prototype.toString.call(arg) === '[object Array]'
  }
  return Array.isArray(arg)
}

/**
 * @Author      gaoxiang
 * @DateTime    2019/11/29
 * @lastTime    2019/11/29
 * @description 是否是对象
 */
function isObject(val) {
  return val !== null && is(val, 'Object')
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否是端口号
 * @param value
 * @returns {boolean}
 */
function isPort(value) {
  const reg = /^([0-9]|[1-9]\d|[1-9]\d{2}|[1-9]\d{3}|[1-5]\d{4}|6[0-4]\d{3}|65[0-4]\d{2}|655[0-2]\d|6553[0-5])$/
  return reg.test(value)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否是手机号
 * @param value
 * @returns {boolean}
 */
function isPhone(value) {
  const reg = /^1\d{10}$/
  return reg.test(value)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否是身份证号(第二代)
 * @param value
 * @returns {boolean}
 */
function isIdCard(value) {
  const reg = /^[1-9]\d{5}(18|19|([23]\d))\d{2}((0[1-9])|(10|11|12))(([0-2][1-9])|10|20|30|31)\d{3}[0-9Xx]$/
  return reg.test(value)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否是邮箱
 * @param value
 * @returns {boolean}
 */
function isEmail(value) {
  const reg = /^\w+([-+.]\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*$/
  return reg.test(value)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否中文
 * @param value
 * @returns {boolean}
 */
function isChina(value) {
  const reg = /^[\u4E00-\u9FA5]{2,4}$/
  return reg.test(value)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否为空
 * @param value
 * @returns {boolean}
 */
function isBlank(value) {
  return (
    value == null ||
    false ||
    value === '' ||
    value.trim() === '' ||
    value.toLocaleLowerCase().trim() === 'null'
  )
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否为固话
 * @param value
 * @returns {boolean}
 */
function isTel(value) {
  const reg = /^(400|800)([0-9\\-]{7,10})|(([0-9]{4}|[0-9]{3})([- ])?)?([0-9]{7,8})(([- 转])*([0-9]{1,4}))?$/
  return reg.test(value)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断经度 -180.0～+180.0（整数部分为0～180，必须输入1到5位小数）
 * @param value
 * @returns {boolean}
 */
function isLongitude(value) {
  const reg = /^[-|+]?(0?\d{1,2}\.\d{1,5}|1[0-7]?\d{1}\.\d{1,5}|180\.0{1,5})$/
  return reg.test(value)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断纬度 -90.0～+90.0（整数部分为0～90，必须输入1到5位小数）
 * @param value
 * @returns {boolean}
 */
function isLatitude(value) {
  const reg = /^[-|+]?([0-8]?\d{1}\.\d{1,5}|90\.0{1,5})$/
  return reg.test(value)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description rtsp校验，只要有rtsp://
 * @param value
 * @returns {boolean}
 */
function isRTSP(value) {
  const reg = /^rtsp:\/\/([a-z]{0,10}:.{0,10}@)?(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])$/
  const reg1 = /^rtsp:\/\/([a-z]{0,10}:.{0,10}@)?(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5]):[0-9]{1,5}/
  const reg2 = /^rtsp:\/\/([a-z]{0,10}:.{0,10}@)?(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\//
  return reg.test(value) || reg1.test(value) || reg2.test(value)
}

/**
 * @Author      gaoxiang
 * @DateTime    2020/11/4
 * @lastTime    2020/11/4
 * @description 判断是否是JSON字符串
 */
function isJSONStr(str) {
  if (typeof str === 'string') {
    try {
      const obj = JSON.parse(str)
      if (typeof obj === 'object' && obj) {
        return true
      } else {
        return false
      }
    } catch (e) {
      return false
    }
  }
  return false
}

function checkURL(URL) {
  const str = URL,
    Expression = /http(s)?:\/\/([\w-]+\.)+[\w-]+(\/[\w- .\/?%&=]*)?/,
    objExp = new RegExp(Expression)
  return objExp.test(str)
}
